Package: TEMPLATE
Type: rave-pipeline
Title: Please Add Title About What Your Pipeline Does in Caption Style
Version: 0.0.1
Language: en-US
Encoding: UTF-8
License: MIT
Authors@R: c(
    person("your first name", "last/family name", email = "your.email@edu", role = c("aut", "cre"))
    )
Description: Add short sentences to describe what this pipeline does
BugReports: https://github.com/your_github_name/pipeline_repository/issues
URL: https://github.com/your_github_name/pipeline_repository
