# Generated by roxygen2: do not edit by hand

S3method("!=",RAVESerializable)
S3method("$",ravepipeline_fastmap2)
S3method("$<-",ravepipeline_fastmap2)
S3method("$<-",ravepipeline_fastqueue2)
S3method("==",RAVESerializable)
S3method("[",PipelineTools)
S3method("[",RAVEFileArray)
S3method("[",ravepipeline_fastmap2)
S3method("[",ravepipeline_fastqueue2)
S3method("[<-",RAVEFileArray)
S3method("[<-",ravepipeline_fastmap2)
S3method("[<-",ravepipeline_fastqueue2)
S3method("[[",ravepipeline_fastmap2)
S3method("[[",ravepipeline_fastqueue2)
S3method("[[<-",ravepipeline_fastmap2)
S3method("[[<-",ravepipeline_fastqueue2)
S3method(as.list,ravepipeline_fastmap2)
S3method(as.list,ravepipeline_fastqueue2)
S3method(as.promise,PipelineResult)
S3method(as.promise,ravepipeline_job_status)
S3method(as.promise,ravepipeline_jobid)
S3method(c,base64_png)
S3method(format,PipelineTools)
S3method(format,base64_png)
S3method(format,raveModuleDescription)
S3method(length,ravepipeline_fastmap2)
S3method(length,ravepipeline_fastqueue2)
S3method(logger_error_condition,callr_error)
S3method(logger_error_condition,character)
S3method(logger_error_condition,default)
S3method(logger_error_condition,rave_error)
S3method(logger_error_condition,rlang_error)
S3method(logger_error_condition,tar_condition_targets)
S3method(names,ravepipeline_fastmap2)
S3method(plot,ravepipeline_plot_data)
S3method(print,"rave-module-registry")
S3method(print,base64_png)
S3method(print,raveModuleDescription)
S3method(print,rave_logs)
S3method(print,rave_snippet)
S3method(print,ravepipeline_bytes)
S3method(print,ravepipeline_fastmap2)
S3method(print,ravepipeline_fastqueue2)
S3method(print,ravepipeline_html_embed_manifest)
S3method(print,ravepipeline_job_status)
S3method(print,ravepipeline_jobid)
S3method(print,ravepipeline_plot_data)
S3method(rave_serialize_impl,"rave-brain")
S3method(rave_serialize_impl,RAVESerializable)
S3method(rave_serialize_impl,default)
S3method(rave_unserialize_impl,"rave_serialized_rave-brain")
S3method(rave_unserialize_impl,default)
S3method(rave_unserialize_impl,rave_serialized)
S3method(rave_unserialize_impl,rave_serialized_r6)
export("%...!%")
export("%...>%")
export("%...T!%")
export("%...T>%")
export(PIPELINE_FORK_PATTERN)
export(PipelineCollections)
export(PipelineResult)
export(PipelineTools)
export(RAVEFileArray)
export(RAVESerializable)
export(add_module_registry)
export(as.promise)
export(base64_decode)
export(base64_encode)
export(base64_plot)
export(base64_urldecode)
export(base64_urlencode)
export(check_job)
export(configure_knitr)
export(digest)
export(dir_create2)
export(get_module_description)
export(get_modules_registries)
export(glue)
export(html_embed_read)
export(html_embed_write)
export(install_modules)
export(install_snippet)
export(lapply_jobs)
export(list_snippets)
export(load_snippet)
export(load_targets)
export(load_yaml)
export(logger)
export(logger_error_condition)
export(logger_threshold)
export(module_add)
export(module_registry)
export(module_registry2)
export(pipeline)
export(pipeline_attach)
export(pipeline_build)
export(pipeline_clean)
export(pipeline_collection)
export(pipeline_create_subject_pipeline)
export(pipeline_create_template)
export(pipeline_debug)
export(pipeline_dep_targets)
export(pipeline_description)
export(pipeline_eval)
export(pipeline_export_wizard)
export(pipeline_find)
export(pipeline_fork)
export(pipeline_from_path)
export(pipeline_get_preferences)
export(pipeline_has_preferences)
export(pipeline_hasname)
export(pipeline_import_wizard)
export(pipeline_install_github)
export(pipeline_install_local)
export(pipeline_list)
export(pipeline_load_extdata)
export(pipeline_plot_data)
export(pipeline_progress)
export(pipeline_read)
export(pipeline_render)
export(pipeline_root)
export(pipeline_run)
export(pipeline_run_bare)
export(pipeline_save_extdata)
export(pipeline_set_preferences)
export(pipeline_settings_get)
export(pipeline_settings_set)
export(pipeline_setup_rmd)
export(pipeline_shared)
export(pipeline_target_names)
export(pipeline_translate_settings)
export(pipeline_vartable)
export(pipeline_visualize)
export(pipeline_watch)
export(rave_progress)
export(rave_serialize_impl)
export(rave_serialize_refhook)
export(rave_unserialize_impl)
export(rave_unserialize_refhook)
export(raveio_confpath)
export(raveio_getopt)
export(raveio_resetopt)
export(raveio_setopt)
export(ravepipeline_finalize_installation)
export(remove_job)
export(resolve_job)
export(save_yaml)
export(set_logger_path)
export(start_job)
export(update_local_snippet)
export(with_rave_parallel)
importFrom(R6,R6Class)
importFrom(R6,is.R6)
importFrom(R6,is.R6Class)
importFrom(digest,digest)
importFrom(glue,glue)
importFrom(promises,"%...!%")
importFrom(promises,"%...>%")
importFrom(promises,"%...T!%")
importFrom(promises,"%...T>%")
importFrom(promises,as.promise)
importFrom(remotes,install_deps)
importFrom(utils,capture.output)
importFrom(utils,head)
importFrom(utils,str)
